<?
/*
Plugin Name: Fotolog widget
Plugin URI: http://www.peix.org/code/fotolog-widget
Description: Adds a widget with the latest photos of your fotolog.com account using the new rss
Author: Miguel Ibero
Version: 0.3
Author URI: http://www.peix.org/about/
*/

// 20-04-2007 version 0.1: initial release
// 20-05-2007 version 0.2: support for friends feed
// 01-07-2007 version 0.2.5: fixed redirecting headers on feeds
// 16-07-2007 version 0.2.6: fixed small cache bug, utf-8 now sent correct, weird hex in feed
// 17-02-2008 version 0.2.7: minor change of fotolog feed urls
// 29-04-2010 version 0.3: remade code to use Widget class and simplepie, added advanced format option

class WP_Widget_Fotolog extends WP_Widget {

    var $urls = array(
        'user'    => "http://feed.fotolog.com/{user}/feed/main/rss20",
        'friends' => "http://feed.fotolog.com/{user}/feed/ff/rss20",
    );

    var $defaults =  array(
        'title'     => 'My Fotolog photos',
        'user'      => 'manny_rodriguez',
        'count'     => 10,
        'feed'      => 'user',
        'format'    => "<span class=\"photo\">\n<a href=\"{link}\"><img src=\"{url}\" alt=\"{text}\" title=\"{title}\"/></a>\n</span>\n",
    );

	function WP_Widget_Fotolog() {
		$widget_ops = array('classname' => 'widget_fotolog', 'description' => __( 'Display your latest fotolog.com photos') );
		$this->WP_Widget('fotolog', __('Fotolog photos'), $widget_ops);
	}

	function widget( $args, $instance ) {
		extract($args);
		$title = apply_filters('widget_title', empty( $instance['title'] ) ? __( 'My Fotolog photos' ) : $instance['title'], $instance, $this->id_base);
		$feed = empty( $instance['feed'] ) ? 'user' : $instance['feed'];
		$user = $instance['user'];
		$format = $instance['format'];
		$count = (int) $instance['count'];
        $url = str_replace('{user}',$user,$this->urls[$feed]);
        $rss = fetch_feed($url);
        $html = "";

        if(is_wp_error($rss)){
            $html .= $rss->get_error_message();
        }else{
            foreach ( $rss->get_items(0, $count) as $item ) {
                $content = trim($item->get_description());
                preg_match('/^<a href="([^"]+)"><img src="([^"\n ]+)/',$content,$match);
                $vars = array(
                    '{title}'   => $item->get_title(),
                    '{link}'    => trim($match[1]),
                    '{url}'     => trim($match[2]),
                );
                if($enc = $item->get_enclosure()){
                    if($caption = $enc->get_caption()){
                        $vars['{text}'] = preg_replace("/[\n\t ]+/"," ",strip_tags($caption->get_text()));
                    }
                }
                $html .= strtr($format ,$vars);
            }
        }

		if (!empty($html)){
			echo $before_widget;
			if($title){
				echo $before_title.$title.$after_title;
            }
            echo $html.$after_widget;
		}
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
        $instance['user'] = strip_tags( $new_instance['user'] );
        $instance['format'] = $new_instance['format'];
		$instance['count'] = (int) $new_instance['count'];
		if ( in_array( $new_instance['feed'], array( 'user', 'friends') ) ) {
			$instance['feed'] = $new_instance['feed'];
		} else {
			$instance['feed'] = 'user';
		}
		return $instance;
	}

	function form( $instance ) {
		//Defaults
		$instance = wp_parse_args( (array) $instance, $this->defaults);
		$title = esc_attr( $instance['title'] );
		$user = esc_attr( $instance['user'] );
		$count = esc_attr( $instance['count'] );
		$feed = esc_attr( $instance['feed'] );
		$format = esc_attr( $instance['format'] );
	?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title'); ?>:</label> <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></p>
		<p><label for="<?php echo $this->get_field_id('user'); ?>">Fotolog.com <?php _e('Login'); ?>:</label> <input class="widefat" id="<?php echo $this->get_field_id('user'); ?>" name="<?php echo $this->get_field_name('user'); ?>" type="text" value="<?php echo $user; ?>" /></p>
		<p><label for="<?php echo $this->get_field_id('count'); ?>"><?php _e('Number of photos'); ?>:</label> <input class="widefat" id="<?php echo $this->get_field_id('count'); ?>" name="<?php echo $this->get_field_name('count'); ?>" type="text" value="<?php echo $count; ?>" /></p>
		<p>
			<label for="<?php echo $this->get_field_id('feed'); ?>"><?php _e( 'Feed type' ); ?>:</label>
			<select name="<?php echo $this->get_field_name('feed'); ?>" id="<?php echo $this->get_field_id('feed'); ?>" class="widefat">
				<option value="user"<?php selected( $instance['feed'], 'user' ); ?>><?php _e('latest photos'); ?></option>
				<option value="friends"<?php selected( $instance['feed'], 'friends' ); ?>><?php _e('friends photos'); ?></option>
			</select>
		</p>
		<p><label for="<?php echo $this->get_field_id('format'); ?>"><?php _e('Item format'); ?>:</label> <textarea class="widefat" id="<?php echo $this->get_field_id('format'); ?>" name="<?php echo $this->get_field_name('format'); ?>"><?php echo $format; ?></textarea></p>

<?php
	}
}

add_action('widgets_init', create_function('', 'return register_widget("WP_Widget_Fotolog");'));

?>
